@@ -31,8 +31,12 @@ around BUILDARGS => sub {
     if (  ref($args) eq 'HASH'
             && defined($args->{CONNECTOR})
             && defined($args->{TARGET}) ) {
-                
-            $args->{LOOPBACK} = Connector::Wrapper->new( $args );                
+        
+            my %arg = %{$args};        
+            $arg{'BASECONNECTOR'} = $arg{CONNECTOR};
+            delete $arg{CONNECTOR};
+                           
+            $args->{LOOPBACK} = Connector::Wrapper->new( %arg );                
     }
     
     return $class->$orig(@_);
